=======
Credits
=======

Development Lead
----------------

* Caleb Lareau <caleblareau@g.harvard.edu>

Supervisor
---------------

* Martin Aryee <Aryee.Martin@mgh.harvard.edu>

Contributors
------------

* Alejandro Reyes <alejandro.reyes.ds@gmail.com>
* Afif Elghraoui

